@@ -16,11 +16,13 @@ using System.Collections.Specialized;
 using System.Web;
 using Mono.Unix;
 using Hyena;
+using Hyena.Widgets;
 
 using FSpot;
 using FSpot.Filters;
 using FSpot.Widgets;
 using FSpot.Utils;
+using FSpot.Imaging;
 using FSpot.UI.Dialog;
 
 using Gnome.Keyring;
@@ -286,7 +288,7 @@ namespace FSpotGoogleExport {
 
 			if (show_captcha) {
 				try {
-					using  (ImageFile img = ImageFile.Create(new SafeUri(captcha_exception.CaptchaUrl, true))) {
+					using  (var img = ImageFile.Create(new SafeUri(captcha_exception.CaptchaUrl, true))) {
 						captcha_image.Pixbuf = img.Load();
 						token = captcha_exception.Token;
 					}
@@ -498,11 +500,8 @@ namespace FSpotGoogleExport {
 			HandleSizeActive (null, null);
 			Connect ();
 
-			scale_check.Toggled += HandleScaleCheckToggled;
-
 			LoadPreference (SCALE_KEY);
 			LoadPreference (SIZE_KEY);
-			LoadPreference (ROTATE_KEY);
 			LoadPreference (BROWSER_KEY);
 //			LoadPreference (Preferences.EXPORT_PICASAWEB_META);
 			LoadPreference (TAG_KEY);
@@ -511,7 +510,6 @@ namespace FSpotGoogleExport {
 		private bool scale;
 		private int size;
 		private bool browser;
-		private bool rotate;
 //		private bool meta;
 		private bool export_tag;
 		private bool connect = false;
@@ -536,7 +534,6 @@ namespace FSpotGoogleExport {
 		public const string EXPORT_SERVICE = "picasaweb/";
 		public const string SCALE_KEY = Preferences.APP_FSPOT_EXPORT + EXPORT_SERVICE + "scale";
 		public const string SIZE_KEY = Preferences.APP_FSPOT_EXPORT + EXPORT_SERVICE + "size";
-		public const string ROTATE_KEY = Preferences.APP_FSPOT_EXPORT + EXPORT_SERVICE + "rotate";
 		public const string BROWSER_KEY = Preferences.APP_FSPOT_EXPORT + EXPORT_SERVICE + "browser";
 		public const string TAG_KEY = Preferences.APP_FSPOT_EXPORT + EXPORT_SERVICE + "tag";
 
@@ -553,7 +550,6 @@ namespace FSpotGoogleExport {
 
 		[Glade.Widget] Gtk.CheckButton browser_check;
 		[Glade.Widget] Gtk.CheckButton scale_check;
-		[Glade.Widget] Gtk.CheckButton rotate_check;
 //		[Glade.Widget] Gtk.CheckButton meta_check;
 		[Glade.Widget] Gtk.CheckButton tag_check;
 
@@ -584,7 +580,6 @@ namespace FSpotGoogleExport {
 				scale = false;
 
 			browser = browser_check.Active;
-			rotate = rotate_check.Active;
 //			meta = meta_check.Active;
 			export_tag = tag_check.Active;
 
@@ -603,7 +598,6 @@ namespace FSpotGoogleExport {
 				// Save these settings for next time
 				Preferences.Set (SCALE_KEY, scale);
 				Preferences.Set (SIZE_KEY, size);
-				Preferences.Set (ROTATE_KEY, rotate);
 				Preferences.Set (BROWSER_KEY, browser);
 //				Preferences.Set (Preferences.EXPORT_GALLERY_META, meta);
 				Preferences.Set (TAG_KEY, export_tag);
@@ -646,9 +640,6 @@ namespace FSpotGoogleExport {
 			if (scale)
 				filters.Add (new ResizeFilter ((uint)size));
 
-			if (rotate)
-				filters.Add (new OrientationFilter ());
-
 			Array.Sort (items, new DateComparer ());
 
 			while (photo_index < items.Length) {
@@ -712,11 +703,6 @@ namespace FSpotGoogleExport {
 			}
 		}
 
-		private void HandleScaleCheckToggled (object o, EventArgs e)
-		{
-			rotate_check.Sensitive = !scale_check.Active;
-		}
-
 		private void PopulateGoogleOptionMenu (GoogleAccountManager manager, GoogleAccount changed_account)
 		{
 			Gtk.Menu menu = new Gtk.Menu ();
@@ -924,7 +910,6 @@ namespace FSpotGoogleExport {
 			case SCALE_KEY:
 				if (scale_check.Active != Preferences.Get<bool> (key)) {
 					scale_check.Active = Preferences.Get<bool> (key);
-					rotate_check.Sensitive = ! Preferences.Get<bool> (key);
 				}
 				break;
 
@@ -937,16 +922,6 @@ namespace FSpotGoogleExport {
 					browser_check.Active = Preferences.Get<bool> (key);
 				break;
 
-			case ROTATE_KEY:
-				if (rotate_check.Active != Preferences.Get<bool> (key))
-					rotate_check.Active = Preferences.Get<bool> (key);
-				break;
-
-//			case Preferences.EXPORT_GALLERY_META:
-//				if (meta_check.Active != (bool) val)
-//					meta_check.Active = (bool) val;
-//				break;
-
 			case TAG_KEY:
 				if (tag_check.Active != Preferences.Get<bool> (key))
 					tag_check.Active = Preferences.Get<bool> (key);
