@@ -18,18 +18,16 @@ namespace FSpot.Extensions
 	public class ComplexMenuItemNode : MenuNode
 	{
 		[NodeAttribute]
-		string widget_type;
+		protected string widget_type;
 
 		[NodeAttribute]
-		string command_type;
-
-		public event EventHandler Changed;
+		protected string command_type;
 
 		ICommand cmd;
 
-		public override Gtk.MenuItem GetMenuItem ()
+		public override Gtk.MenuItem GetMenuItem (object parent)
 		{
-			ComplexMenuItem item = System.Activator.CreateInstance (Type.GetType (widget_type)) as ComplexMenuItem;
+			ComplexMenuItem item = System.Activator.CreateInstance (Type.GetType (widget_type), parent) as ComplexMenuItem;
 			cmd = (ICommand) Addin.CreateInstance (command_type);
 			
 			if (item != null)
