@@ -1,21 +1,49 @@
+/* 
+ * FSpot.Histogram.cs
+ *
+ * Author(s):
+ *	Larry Ewing  <lewing@novell.com>
+ *	Ruben Vermeersch  <ruben@savanne.be>
+ *
+ * This is free software, See COPYING for details.
+ */
+
 using System;
 
 namespace FSpot {
 	public class Histogram {
+#region Color hints
+		private byte [] colors = new byte [] {0x00, 0x00, 0x00, 0xff};
+
+		public byte RedColorHint {
+			set { colors [0] = value; }
+		}
+
+		public byte GreenColorHint {
+			set { colors [1] = value; }
+		}
+
+		public byte BlueColorHint {
+			set { colors [2] = value; }
+		}
+
+		public byte BackgroundColorHint {
+			set { colors [3] = value; }
+		}
+
+		private int [,] values = new int [256, 3];
+#endregion
+
 		public Histogram (Gdk.Pixbuf src)
 		{
 		        FillValues (src);
 		}
 		
 		public Histogram () {}
-		
-		// FIXME these should be properties
-		public byte [] Color = new byte [] {0x00, 0x00, 0x00, 0xff};
-
-		public void FillValues (Gdk.Pixbuf src)
 
+		private void FillValues (Gdk.Pixbuf src)
 		{
-			values = new int [265, 3];
+			values = new int [256, 3];
 
 			if (src.BitsPerSample != 8)
 				throw new System.Exception ("Invalid bits per sample");
@@ -45,12 +73,50 @@ namespace FSpot {
 					}
 				}
 			}
-			if (pixbuf != null) {
-				FillPixbuf (pixbuf);
-			}
 		}
 		
-		private void FillPixbuf (Gdk.Pixbuf image) 
+		private int ChannelSum (int channel)
+		{
+			int sum = 0;
+			for (int i = 0; i < values.GetLength (0); i++) {
+				sum += values [i, channel];
+			}
+
+			return sum;
+		}
+
+		public void GetHighLow (int channel, out int high, out int low)
+		{
+			double total = ChannelSum (channel);
+			double current = 0.0;
+			double percentage;
+			double next_percentage;
+			
+			low = 0;
+			high = 0;
+			
+			for (int i = 0; i < values.GetLength (0) - 1; i++) {
+				current += values [i, channel];
+				percentage = current / total;
+				next_percentage = (current + values [i + 1, channel]) / total;
+				if (Math.Abs (percentage - 0.006) < Math.Abs (next_percentage - 0.006)) {
+					low = i + 1;
+					break;
+				}
+			}
+
+			for (int i = values.GetLength (0) - 1; i > 0; i--) {
+				current += values [i, channel];
+				percentage = current / total;
+				next_percentage = (current + values [i - 1, channel]) / total;
+				if (Math.Abs (percentage - 0.006) < Math.Abs (next_percentage - 0.006)) {
+					high = i - 1;
+					break;
+				}
+			}
+		}
+
+		private void Draw (Gdk.Pixbuf image) 
 		{
 			int max = 0;
 			for (int i = 0; i < values.GetLength (0); i++) {
@@ -79,10 +145,10 @@ namespace FSpot {
 
 					int j = 0;
 					for (; j < height - top; j++) {
-						pixels [0] = Color [0];
-						pixels [1] = Color [1];
-						pixels [2] = Color [2];
-						pixels [3] = Color [3];
+						pixels [0] = colors [0];
+						pixels [1] = colors [1];
+						pixels [2] = colors [2];
+						pixels [3] = colors [3];
 						pixels += rowstride;
 					}
 					for (; j < height; j++) {
@@ -97,40 +163,36 @@ namespace FSpot {
 			}
 		}	
 
-		public Gdk.Pixbuf GeneratePixbuf ()
+		public Gdk.Pixbuf Generate (Gdk.Pixbuf input, int max_width)
 		{
+			Gdk.Pixbuf scaled;
+			using (Gdk.Pixbuf pixbuf = Generate (input))
+				scaled = PixbufUtils.ScaleToMaxSize (pixbuf, max_width, 128);
+			return scaled;
+		}
+
+		public Gdk.Pixbuf Generate (Gdk.Pixbuf input)
+		{
+			FillValues (input);
 			int height = 128;
-			pixbuf = new Gdk.Pixbuf (Gdk.Colorspace.Rgb, true, 8, values.GetLength (0), height);
-			this.FillPixbuf (pixbuf);
+			Gdk.Pixbuf pixbuf = new Gdk.Pixbuf (Gdk.Colorspace.Rgb, true, 8, values.GetLength (0), height);
+			Draw (pixbuf);
 			return pixbuf;
 		}
 						     
-		private int [,] values = new int [256, 3];
-		public int [,] Values {
-			get {
-				return values;
-			}
-		}
-		
-		private Gdk.Pixbuf pixbuf;
-		public Gdk.Pixbuf Pixbuf {
-			get {
-				return pixbuf;
-			}
-		}
 		
 #if FSPOT_HISTOGRAM_MAIN
 		public static void Main (string [] args) 
 		{
 			Gtk.Application.Init ();
 			Gdk.Pixbuf pixbuf = new Gdk.Pixbuf (args [0]);
-			System.Console.WriteLine ("loaded {0}", args [0]);
-			Histogram hist = new Histogram (pixbuf);
-			System.Console.WriteLine ("loaded histgram", args [0]);
+			Log.DebugFormat ("loaded {0}", args [0]);
+			Histogram hist = new Histogram ();
+			Log.DebugFormat ("loaded histgram", args [0]);
 			
 			Gtk.Window win = new Gtk.Window ("display");
 			Gtk.Image image = new Gtk.Image ();
-			Gdk.Pixbuf img = hist.GeneratePixbuf ();
+			Gdk.Pixbuf img = hist.Generate (pixbuf);
 			image.Pixbuf = img;
 			win.Add (image);
 			win.ShowAll ();
