@@ -13,28 +13,30 @@ using FSpot.Widgets;
 namespace FSpot {
 	public class InfoItem : InfoBox {
 		BrowsablePointer item;
-
+		
 		public InfoItem (BrowsablePointer item)
 		{
 			this.item = item;
 			item.Changed += HandleItemChanged;
 			HandleItemChanged (item, null);
-			VersionIdChanged += HandleVersionIdChanged;
+			VersionChanged += HandleVersionChanged;
 			ShowTags = true;
+			ShowRating = true;
+			Context = ViewContext.FullScreen;
 		}
-
-		private void HandleItemChanged (BrowsablePointer sender, BrowsablePointerChangedArgs args)
+		
+		private void HandleItemChanged (object sender, BrowsablePointerChangedEventArgs args)
 		{
 			Photo = item.Current;
 		}
 
-		private void HandleVersionIdChanged (InfoBox box, uint version_id)
+		private void HandleVersionChanged (InfoBox box, IBrowsableItemVersion version)
 		{
-			Photo p = item.Current as Photo;
+			IBrowsableItemVersionable versionable = item.Current as IBrowsableItemVersionable;
 			PhotoQuery q = item.Collection as PhotoQuery;
 
-			if (p !=  null && q != null) {
-				p.DefaultVersionId  = version_id;
+			if (versionable != null && q != null) {
+				versionable.SetDefaultVersion (version);
 				q.Commit (item.Index);
 			}
 		}
@@ -47,10 +49,11 @@ namespace FSpot {
 		{
 			XAlign = 1.0;
 			YAlign = 0.1;
+			DefaultWidth = 250;
 			box = new InfoItem (item);
 			box.BorderWidth = 15;
 			Add (box);
-			box.Show ();
+			box.ShowAll ();
 			Visibility = VisibilityType.Partial;
 			KeepAbove = true;
 			//WindowPosition = WindowPosition.Mouse;
