@@ -1,14 +1,34 @@
+/*
+ * FSpot.QueryWidget.cs
+ *
+ * Author(s):
+ *	Gabriel Burt
+ *
+ * This is free software. See COPYING for details.
+ */
+
+
+using System;
+using System.Collections.Generic;
+
+using Mono.Unix;
+
+using Gtk;
+
+using FSpot.Utils;
 using FSpot.Query;
 using FSpot.Widgets;
-using Mono.Unix;
-using Gtk;
+using Hyena;
+
 
 namespace FSpot {
 
 	public class QueryWidget : HighlightedBox {
 		PhotoQuery query;
 		LogicWidget logic_widget;
-	        Gtk.HBox box;
+		FolderQueryWidget folder_query_widget;
+		
+		Gtk.HBox box;
 		Gtk.Label label;
 		Gtk.Label untagged;
 		Gtk.Label rated;
@@ -18,22 +38,17 @@ namespace FSpot {
 		Gtk.HBox warning_box;
 		Gtk.Button clear_button;
 		Gtk.Button refresh_button;
-		Gtk.Tooltips tips = new Gtk.Tooltips ();
 
 		public LogicWidget Logic {
-			get {
-				return logic_widget;
-			}
+			get { return logic_widget; }
 		}
 
-		public QueryWidget (PhotoQuery query, Db db, TagSelectionWidget selector) : base(new HBox())
+		public QueryWidget (PhotoQuery query, Db db) : base(new HBox())
 		{
 			box = Child as HBox;
 			box.Spacing = 6;
 			box.BorderWidth = 2;
 
-			tips.Enable ();
-
 			this.query = query;
 			query.Changed += HandleChanged;
 
@@ -58,11 +73,16 @@ namespace FSpot {
 			comma2_label.Visible = false;
 			box.PackStart (comma2_label, false, false, 0);
 
+			// Note for translators: 'Import roll' is no command, it means 'Roll that has been imported' 
 			rollfilter = new Gtk.Label (Catalog.GetString ("Import roll"));	
 			rollfilter.Visible = false;
 			box.PackStart (rollfilter, false, false, 0);
 
-			logic_widget = new LogicWidget (query, db.Tags, selector);
+			folder_query_widget = new FolderQueryWidget (query);
+			folder_query_widget.Visible = false;
+			box.PackStart (folder_query_widget, false, false, 0);
+			
+			logic_widget = new LogicWidget (query, db.Tags);
 			logic_widget.Show ();
 			box.PackStart (logic_widget, true, true, 0);
 
@@ -77,15 +97,15 @@ namespace FSpot {
 			clear_button.Add (new Gtk.Image ("gtk-close", Gtk.IconSize.Button));
 			clear_button.Clicked += HandleClearButtonClicked;
 			clear_button.Relief = Gtk.ReliefStyle.None;
+			clear_button.TooltipText = Catalog.GetString("Clear search");
 			box.PackEnd (clear_button, false, false, 0);
-			tips.SetTip (clear_button, Catalog.GetString("Clear search"), null);
 			
 			refresh_button = new Gtk.Button ();
 			refresh_button.Add (new Gtk.Image ("gtk-refresh", Gtk.IconSize.Button));
 			refresh_button.Clicked += HandleRefreshButtonClicked;
 			refresh_button.Relief = Gtk.ReliefStyle.None;
+			refresh_button.TooltipText = Catalog.GetString("Refresh search");
 			box.PackEnd (refresh_button, false, false, 0);
-			tips.SetTip (refresh_button, Catalog.GetString("Refresh search"), null);
 
 			Gtk.Label warning = new Gtk.Label (Catalog.GetString ("No matching photos found"));
 			warning_box.PackStart (warning, false, false, 0);
@@ -119,30 +139,36 @@ namespace FSpot {
 			query.RatingRange = null;
 			logic_widget.Clear = true;
 			logic_widget.UpdateQuery ();
+			
+			folder_query_widget.Clear ();
+			query.RequestReload ();
+			
+			HideBar ();
 		}
 
 		public void ShowBar ()
 		{
 			Show ();
-			((Gtk.Label)MainWindow.Toplevel.FindByTag.Child).TextWithMnemonic = Catalog.GetString ("Hide _Find Bar");
 		}
 
 		public void HideBar ()
 		{
 			Hide ();
-			((Gtk.Label)MainWindow.Toplevel.FindByTag.Child).TextWithMnemonic = Catalog.GetString ("Show _Find Bar");
 		}
 
 		public void HandleChanged (IBrowsableCollection collection) 
 		{
-			if (query.ExtraCondition == null)
+			if (query.TagTerm == null)
 				logic_widget.Clear = true;
 
-			if (!logic_widget.Clear || query.Untagged || (query.RollSet != null) || (query.RatingRange != null)) {
-		                ShowBar ();
-			} else {
+			if ( ! logic_widget.Clear
+			    || query.Untagged
+			    || (query.RollSet != null)
+			    || (query.RatingRange != null)
+			    || ! folder_query_widget.Empty)
+				ShowBar ();
+			else
 				HideBar ();
-			}
 
 			untagged.Visible = query.Untagged;
 			rated.Visible = (query.RatingRange != null);
@@ -188,5 +214,11 @@ namespace FSpot {
 		{
 			return logic_widget.TagRequired (tag);
 		}
+		
+		public void SetFolders (IEnumerable<SafeUri> uri_list)
+		{
+			folder_query_widget.SetFolders (uri_list);
+			query.RequestReload ();
+		}
 	}
 }
