@@ -12,6 +12,7 @@
  */
 
 using Gtk;
+using Gdk;
 using System;
 using System.Text;
 using System.Collections;
@@ -30,18 +31,18 @@ public class TagCommands {
 		Category
 	}
 
-	public class Create : GladeDialog {
+	public class Create : BuilderDialog {
 		TagStore tag_store;
 
 
-		[Glade.Widget] private Button create_button;
-		[Glade.Widget] private Entry tag_name_entry;
-		[Glade.Widget] private Label prompt_label;
-		[Glade.Widget] private Label already_in_use_label;
-		[Glade.Widget] private Label photo_label;
-		[Glade.Widget] private ScrolledWindow photo_scrolled_window;
-		[Glade.Widget] private OptionMenu category_option_menu;
-		[Glade.Widget] private CheckButton auto_icon_checkbutton;
+		[GtkBeans.Builder.Object] private Button create_button;
+		[GtkBeans.Builder.Object] private Entry tag_name_entry;
+		[GtkBeans.Builder.Object] private Label prompt_label;
+		[GtkBeans.Builder.Object] private Label already_in_use_label;
+		[GtkBeans.Builder.Object] private Label photo_label;
+		[GtkBeans.Builder.Object] private ScrolledWindow photo_scrolled_window;
+		[GtkBeans.Builder.Object] private ComboBox category_option_menu;
+		[GtkBeans.Builder.Object] private CheckButton auto_icon_checkbutton;
 
 		Gtk.Widget parent_window;
 
@@ -57,21 +58,43 @@ public class TagCommands {
 			}
 		}
 
+		private string Indentation (Category category)
+		{
+			int indentations = 0;
+			for (Category parent = category.Category;
+			     parent != null && parent.Category != null;
+			     parent = parent.Category)
+				indentations++;
+			return new string (' ', indentations*2);
+		}
+
 		private void PopulateCategoryOptionMenu ()
 		{
 			categories = new ArrayList ();
 			categories.Add (tag_store.RootCategory);
 			PopulateCategories (categories, tag_store.RootCategory);
 
-			Menu menu = new Menu ();
+			ListStore category_store = new ListStore (typeof(Pixbuf), typeof(string));
 
-			foreach (Category category in categories)
-				menu.Append (TagMenu.TagMenuItem.IndentedItem (category));
+			foreach (Category category in categories) {
+				category_store.AppendValues (category.SizedIcon, Indentation (category) + category.Name);
+			}
 
 			category_option_menu.Sensitive = true;
 
-			menu.ShowAll ();
-			category_option_menu.Menu = menu;
+			category_option_menu.Model = category_store;
+			var icon_renderer = new CellRendererPixbuf ();
+			icon_renderer.Width = (int)Tag.TagIconSize;
+			category_option_menu.PackStart (icon_renderer, true);
+
+			var text_renderer = new CellRendererText ();
+			text_renderer.Alignment = Pango.Alignment.Left;
+			text_renderer.Width = 150;
+			category_option_menu.PackStart (text_renderer, true);
+
+			category_option_menu.AddAttribute (icon_renderer, "pixbuf", 0);
+			category_option_menu.AddAttribute (text_renderer, "text", 1);
+			category_option_menu.ShowAll ();
 		}
 
 		private bool TagNameExistsInCategory (string name, Category category)
@@ -111,7 +134,7 @@ public class TagCommands {
 				if (categories.Count == 0)
 					return tag_store.RootCategory;
 				else
-					return categories [category_option_menu.History] as Category;
+					return categories [category_option_menu.Active] as Category;
 			}
 			set {
 				if ((value != null) && (categories.Count > 0)) {
@@ -120,29 +143,31 @@ public class TagCommands {
 						Category category = (Category)categories[i];
 						// should there be an equals type method?
 						if (value.Id == category.Id) {
-							category_option_menu.SetHistory((uint)i);
+							category_option_menu.Active = i;
 							return;
 						}
 					}	
+				} else {
+					category_option_menu.Active = 0;
 				}
 			}
 		}
 		
 		public Tag Execute (TagType type, Tag [] selection)
 		{
-			this.CreateDialog ("create_tag_dialog");
-
 			Category default_category = null;
 			if (selection.Length > 0) {
 				if (selection [0] is Category)
 					default_category = (Category) selection [0];
 				else
 					default_category = selection [0].Category;
+			} else {
+				default_category = tag_store.RootCategory;
 			}
 
-			this.Dialog.DefaultResponse = ResponseType.Ok;
+			this.DefaultResponse = ResponseType.Ok;
 
-			this.Dialog.Title = Catalog.GetString ("Create New Tag");
+			this.Title = Catalog.GetString ("Create New Tag");
 			prompt_label.Text = Catalog.GetString ("Name of New Tag:");
 			this.auto_icon_checkbutton.Active = Preferences.Get<bool> (Preferences.TAG_ICON_AUTOMATIC);
 
@@ -151,7 +176,7 @@ public class TagCommands {
 			Update ();
 			tag_name_entry.GrabFocus ();
 
-			ResponseType response = (ResponseType) this.Dialog.Run ();
+			ResponseType response = (ResponseType) this.Run ();
 
 
 			Tag new_tag = null;
@@ -171,11 +196,11 @@ public class TagCommands {
 				}
 			}
 
-			this.Dialog.Destroy ();
+			this.Destroy ();
 			return new_tag;
 		}
 
-		public Create (TagStore tag_store, Gtk.Window parent_window)
+		public Create (TagStore tag_store, Gtk.Window parent_window) : base ("CreateTagDialog.ui", "create_tag_dialog")
 		{
 			this.tag_store = tag_store;
 			this.parent_window = parent_window;
