@@ -17,7 +17,7 @@ using FSpot.Utils;
 public class TagPopup {
 	public void Activate (Gdk.EventButton eb, Tag tag, Tag [] tags)
 	{
-		int photo_count = MainWindow.Toplevel.SelectedPhotos ().Length;
+		int photo_count = App.Instance.Organizer.SelectedPhotos ().Length;
 		int tags_count = tags.Length;
 
 		Gtk.Menu popup_menu = new Gtk.Menu ();
@@ -25,7 +25,7 @@ public class TagPopup {
 		GtkUtil.MakeMenuItem (popup_menu,
                 String.Format (Catalog.GetPluralString ("Find", "Find", tags.Length), tags.Length),
                 "gtk-add",
-                new EventHandler (MainWindow.Toplevel.HandleIncludeTag),
+                new EventHandler (App.Instance.Organizer.HandleIncludeTag),
                 true
         );
 
@@ -34,33 +34,33 @@ public class TagPopup {
 		GtkUtil.MakeMenuSeparator (popup_menu);
 		
 		GtkUtil.MakeMenuItem (popup_menu, Catalog.GetString ("Create New Tag..."), "tag-new",
-				      MainWindow.Toplevel.HandleCreateNewCategoryCommand, true);
+				      App.Instance.Organizer.HandleCreateNewCategoryCommand, true);
 
         GtkUtil.MakeMenuSeparator (popup_menu);
 		
 		GtkUtil.MakeMenuItem (popup_menu,
-			Catalog.GetString ("Edit Selected Tag..."), "gtk-edit",
-			delegate { MainWindow.Toplevel.HandleEditSelectedTagWithTag (tag); }, tag != null && tags_count == 1);
+			Catalog.GetString ("Edit Tag..."), "gtk-edit",
+			delegate { App.Instance.Organizer.HandleEditSelectedTagWithTag (tag); }, tag != null && tags_count == 1);
 
 		GtkUtil.MakeMenuItem (popup_menu,
 			Catalog.GetPluralString ("Delete Tag", "Delete Tags", tags_count), "gtk-delete",
-			new EventHandler (MainWindow.Toplevel.HandleDeleteSelectedTagCommand), tag != null);
+			new EventHandler (App.Instance.Organizer.HandleDeleteSelectedTagCommand), tag != null);
 		
 		GtkUtil.MakeMenuSeparator (popup_menu);
 
 		GtkUtil.MakeMenuItem (popup_menu,
 				      Catalog.GetPluralString ("Attach Tag to Selection", "Attach Tags to Selection", tags_count), "gtk-add",
-				      new EventHandler (MainWindow.Toplevel.HandleAttachTagCommand), tag != null && photo_count > 0);
+				      new EventHandler (App.Instance.Organizer.HandleAttachTagCommand), tag != null && photo_count > 0);
 
 		GtkUtil.MakeMenuItem (popup_menu,
 				      Catalog.GetPluralString ("Remove Tag From Selection", "Remove Tags From Selection", tags_count), "gtk-remove",
-				      new EventHandler (MainWindow.Toplevel.HandleRemoveTagCommand), tag != null && photo_count > 0);
+				      new EventHandler (App.Instance.Organizer.HandleRemoveTagCommand), tag != null && photo_count > 0);
 
 		if (tags_count > 1 && tag != null) {
 			GtkUtil.MakeMenuSeparator (popup_menu);
 
 			GtkUtil.MakeMenuItem (popup_menu, Catalog.GetString ("Merge Tags"),
-					      new EventHandler (MainWindow.Toplevel.HandleMergeTagsCommand), true);
+					      new EventHandler (App.Instance.Organizer.HandleMergeTagsCommand), true);
 
 		}
 
