@@ -5,7 +5,10 @@ using Mono.Unix;
 using Gtk;
 using Gdk;
 
-namespace FSpot.Query
+using FSpot.Utils;
+using FSpot.Query;
+
+namespace FSpot
 {
 	public class LiteralPopup
 	{
@@ -21,7 +24,7 @@ namespace FSpot.Query
 			//this.literal = literal;
 
 			/*MenuItem attach_item = new MenuItem (Catalog.GetString ("Find With"));
-			TagMenu attach_menu = new TagMenu (attach_item, MainWindow.Toplevel.Database.Tags);
+			TagMenu attach_menu = new TagMenu (attach_item, App.Instance.Database.Tags);
 			attach_menu.TagSelected += literal.HandleAttachTagCommand;
 			attach_item.ShowAll ();
 			popup_menu.Append (attach_item);*/
@@ -108,7 +111,7 @@ namespace FSpot.Query
 				//Console.WriteLine ("root is not null and has terms");
 				Gtk.Menu m = new Gtk.Menu ();
 
-				Gtk.MenuItem all_item = GtkUtil.MakeMenuItem (m, Catalog.GetString ("All"), new EventHandler (MainWindow.Toplevel.HandleRequireTag));
+				Gtk.MenuItem all_item = GtkUtil.MakeMenuItem (m, Catalog.GetString ("All"), new EventHandler (App.Instance.Organizer.HandleRequireTag));
 				GtkUtil.MakeMenuSeparator (m);
 
 				int sensitive_items = 0;
@@ -119,7 +122,7 @@ namespace FSpot.Query
 
 					string name = "_" + String.Join (", ", (string []) term_parts.ToArray (typeof(string)));
 
-					Gtk.MenuItem item = GtkUtil.MakeMenuItem (m, name, new EventHandler (MainWindow.Toplevel.HandleAddTagToTerm));
+					Gtk.MenuItem item = GtkUtil.MakeMenuItem (m, name, new EventHandler (App.Instance.Organizer.HandleAddTagToTerm));
 					item.Sensitive = !contains_tag;
 
 					if (!contains_tag)
@@ -205,9 +208,7 @@ namespace FSpot.Query
 
 	public class LogicWidget : HBox {
 		private PhotoQuery query;
-		private TagSelectionWidget tag_selection_widget;
 
-		private static Tooltips tips = new Tooltips ();
 
 		private static Term rootTerm;
 		private EventBox rootAdd;
@@ -233,24 +234,20 @@ namespace FSpot.Query
 		}
 
 		// Drag and Drop
-		private static TargetEntry [] tag_dest_target_table = new TargetEntry [] {
-					new TargetEntry ("application/x-fspot-tags", 0, (uint) MainWindow.TargetType.TagList),
-					new TargetEntry ("application/x-fspot-tag-query-item", 0, (uint) MainWindow.TargetType.TagQueryItem),
-				};
+		private static TargetEntry [] tag_dest_target_table =
+			new TargetEntry [] {
+				DragDropTargets.TagListEntry,
+				DragDropTargets.TagQueryEntry
+			};
 
-		public LogicWidget (PhotoQuery query, TagStore tag_store, TagSelectionWidget selector) : base ()
+		public LogicWidget (PhotoQuery query, TagStore tag_store) : base ()
 		{
 			//SetFlag (WidgetFlags.NoWindow);
 			this.query = query;
-			this.tag_selection_widget = selector;
 
 			CanFocus = true;
 			Sensitive = true;
 
-			Literal.Tips = tips;
-
-			tips.Enable ();
-
 			Init ();
 
 			tag_store.ItemsChanged += HandleTagChanged;
@@ -312,19 +309,19 @@ namespace FSpot.Query
 
 		// When the user edits a tag (it's icon, name, etc) we get called
 		// and update the images/text in the query as needed to reflect the changes.
-		private void HandleTagChanged (object sender, DbItemEventArgs args)
+		private void HandleTagChanged (object sender, DbItemEventArgs<Tag> args)
 		{
-			foreach (DbItem item in args.Items)
-			foreach (Literal term in rootTerm.FindByTag (item as Tag))
-			term.Update ();
+			foreach (Tag t in args.Items)
+                foreach (Literal term in rootTerm.FindByTag (t))
+                    term.Update ();
 		}
 
 		// If the user deletes a tag that is in use in the query, remove it from the query too.
-		private void HandleTagDeleted (object sender, DbItemEventArgs args)
+		private void HandleTagDeleted (object sender, DbItemEventArgs<Tag> args)
 		{
-			foreach (DbItem item in args.Items)
-			foreach (Literal term in rootTerm.FindByTag (item as Tag))
-			term.RemoveSelf ();
+			foreach (Tag t in args.Items)
+                foreach (Literal term in rootTerm.FindByTag (t))
+                    term.RemoveSelf ();
 		}
 
 		private void HandleDragMotion (object o, DragMotionArgs args)
@@ -367,9 +364,9 @@ namespace FSpot.Query
 			UpdateQuery ();
 		}
 
-		private void HandleTermAdded (Term parent, Literal after)
+		private void HandleTagsAdded (Tag[] tags, Term parent, Literal after)
 		{
-			InsertTerm (parent, after);
+			InsertTerm (tags, parent, after);
 		}
 
 		private void HandleAttachTag (Tag tag, Term parent, Literal after)
@@ -426,9 +423,24 @@ namespace FSpot.Query
 
 		private void HandleDragDataReceived (object o, DragDataReceivedArgs args)
 		{
-			InsertTerm (rootTerm, null);
-
 			args.RetVal = true;
+			
+			if (args.Info == DragDropTargets.TagListEntry.Info) {
+
+				InsertTerm (args.SelectionData.GetTagsData (), rootTerm, null);
+				return;
+			}
+			
+			if (args.Info == DragDropTargets.TagQueryEntry.Info) {
+
+				// FIXME: use drag data
+				HandleLiteralsMoved (Literal.FocusedLiterals, rootTerm, null);
+
+				// Prevent them from being removed again
+				Literal.FocusedLiterals = null;
+				
+				return;
+			}
 		}
 
 		/** Helper Functions **/
@@ -593,18 +605,6 @@ namespace FSpot.Query
 			UpdateQuery ();
 		}
 
-		private void InsertTerm (Term parent, Literal after)
-		{
-			if (Literal.FocusedLiterals.Count != 0) {
-				HandleLiteralsMoved (Literal.FocusedLiterals, parent, after);
-
-				// Prevent them from being removed again
-				Literal.FocusedLiterals = null;
-			}
-			else
-				InsertTerm (tag_selection_widget.TagHighlight, parent, after);
-		}
-
 		public ArrayList InsertTerm (Tag [] tags, Term parent, Literal after)
 		{
 			int position;
@@ -641,7 +641,7 @@ namespace FSpot.Query
 				}
 
 				Literal term  = new Literal (parent, tag, after);
-				term.TermAdded  += HandleTermAdded;
+				term.TagsAdded  += HandleTagsAdded;
 				term.LiteralsMoved += HandleLiteralsMoved;
 				term.AttachTag  += HandleAttachTag;
 				term.NegatedToggled += HandleNegated;
@@ -672,11 +672,10 @@ namespace FSpot.Query
 
 			if (rootTerm.Count == 0) {
 				help.Show ();
-				query.ExtraCondition = null;
+				query.TagTerm = null;
 			} else {
 				help.Hide ();
-				query.ExtraCondition = rootTerm.SqlCondition ();
-				//Console.WriteLine ("extra_condition = {0}", query.ExtraCondition);
+				query.TagTerm = new ConditionWrapper (rootTerm.SqlCondition ());
 			}
 
 			EventHandler handler = Changed;
