@@ -10,13 +10,14 @@
 
 using System;
 using System.Collections;
+using System.Text;
 using System.Text.RegularExpressions;
 using Gtk;
 using Gdk;
 using Mono.Unix;
 
 using FSpot.Query;
-using FSpot.Utils;
+using Hyena;
 
 namespace FSpot.Widgets {
 	public class FindBar : HighlightedBox {
@@ -25,7 +26,7 @@ namespace FSpot.Widgets {
 		private int open_parens = 0, close_parens = 0;
 		private PhotoQuery query;
 		private Term root_term = null;
-        private HBox box;
+		private HBox box;
 
 		/*
 		 * Properties
@@ -50,10 +51,10 @@ namespace FSpot.Widgets {
 		public FindBar (PhotoQuery query, TreeModel model) : base(new HBox())
 		{
 			this.query = query;
-            box = Child as HBox;
+			box = Child as HBox;
 
 			box.Spacing = 6;
-            box.BorderWidth = 2;
+			box.BorderWidth = 2;
 
 			box.PackStart (new Label (Catalog.GetString ("Find:")), false, false, 0);
 
@@ -84,7 +85,7 @@ namespace FSpot.Widgets {
 
 		private void HandleEntryTextInserted (object sender, TextInsertedArgs args)
 		{
-			//Log.Debug ("inserting {0}, ( = {1}  ) = {2}", args.Text, open_parens, close_parens);
+			//Log.DebugFormat ("inserting {0}, ( = {1}  ) = {2}", args.Text, open_parens, close_parens);
 
 			//int start = args.Position - args.Length;
 
@@ -105,7 +106,7 @@ namespace FSpot.Widgets {
 				entry.TextInserted += HandleEntryTextInserted;
 				pos++;
 			}
-			//Log.Debugformat ("done w/ insert, {0}, ( = {1}  ) = {2}", args.Text, open_parens, close_parens);
+			//Log.DebugFormat ("done w/ insert, {0}, ( = {1}  ) = {2}", args.Text, open_parens, close_parens);
 			last_entry_text = entry.Text;
 
 			QueueUpdate ();
@@ -114,7 +115,7 @@ namespace FSpot.Widgets {
 		private void HandleEntryTextDeleted (object sender, TextDeletedArgs args)
 		{
 			int length = args.EndPos - args.StartPos;
-			//Log.Debug ("start {0} end {1} len {2} last {3}", args.StartPos, args.EndPos, length, last_entry_text);
+			//Log.DebugFormat ("start {0} end {1} len {2} last {3}", args.StartPos, args.EndPos, length, last_entry_text);
 			string txt = length < 0 ? last_entry_text : last_entry_text.Substring (args.StartPos, length);
 
 			for (int i = 0; i < txt.Length; i++) {
@@ -198,16 +199,6 @@ namespace FSpot.Widgets {
 							  RegexOptions.IgnoreCase | RegexOptions.Compiled
 						  );
 
-		// Debug method used to print results to verify the regex
-		private static void PrintGroup (GroupCollection groups, string name)
-		{
-			Group group = groups [name];
-			Log.Debug ("Name: {2} (success = {1}) group: {0}", group, group.Success, name);
-			foreach (Capture capture in group.Captures) {
-				Log.Debug ("  Have capture: {0}", capture);
-			}
-		}
-
 		// Breaking the query the user typed into something useful involves running
 		// it through the above regular expression recursively until it is broken down
 		// into literals and operators that we can use to generate SQL queries.
@@ -223,7 +214,7 @@ namespace FSpot.Widgets {
 
 			string indent = String.Format ("{0," + depth*2 + "}", " ");
 
-			//Log.Debug (indent + "Have text: {0}", txt);
+			//Log.DebugFormat (indent + "Have text: {0}", txt);
 
 			// Match the query the user typed against our regular expression
 			Match match = term_regex.Match (txt);
@@ -254,7 +245,7 @@ namespace FSpot.Widgets {
 			}
 
 			if (match.Groups ["Terms"].Captures.Count == 1 && match.Groups["NotTerm"].Captures.Count != 1) {
-				//Log.Debug (indent + "Unbreakable term: {0}", match.Groups ["Terms"].Captures [0]);
+				//Log.DebugFormat (indent + "Unbreakable term: {0}", match.Groups ["Terms"].Captures [0]);
 				string literal;
 				bool is_negated = false;
 				Tag tag = null;
@@ -269,7 +260,7 @@ namespace FSpot.Widgets {
 
 				is_negated = is_negated || negated;
 
-				tag = MainWindow.Toplevel.Database.Tags.GetTagByName (literal);
+				tag = App.Instance.Database.Tags.GetTagByName (literal);
 
 				// New OR term so we can match against both tag and text search
 				parent = new OrTerm(parent, null);
@@ -312,7 +303,7 @@ namespace FSpot.Widgets {
 						subterm = subterm.Remove (0, 1);
 					}
 
-					//Log.Debug (indent + "Breaking subterm apart: {0}", subterm);
+					//Log.DebugFormat (indent + "Breaking subterm apart: {0}", subterm);
 
 					if (!ConstructQuery (us, depth + 1, subterm, negated))
 						return false;
@@ -330,7 +321,7 @@ namespace FSpot.Widgets {
 						subterm = subterm.Remove (0, 1);
 					}
 
-					//Log.Debug (indent + "Breaking not subterm apart: {0}", subterm);
+					//Log.DebugFormat (indent + "Breaking not subterm apart: {0}", subterm);
 
 					if (!ConstructQuery (us, depth + 1, subterm, true))
 						return false;
@@ -392,7 +383,7 @@ namespace FSpot.Widgets {
 
 			if (ParensValid () && ConstructQuery (null, 0, entry.Text)) {
 				if (RootTerm != null) {
-					//Log.Debug("rootTerm = {0}", RootTerm);
+					//Log.DebugFormat("rootTerm = {0}", RootTerm);
 					if (!(RootTerm is AndTerm)) {
 						// A little hacky, here to make sure the root term is a AndTerm which will
 						// ensure we handle the Hidden tag properly
@@ -401,7 +392,7 @@ namespace FSpot.Widgets {
 						root_term = root_parent;
 					}
 
-					//Log.Debug("rootTerm = {0}", RootTerm);
+					//Log.DebugFormat("rootTerm = {0}", RootTerm);
 					if (!(RootTerm is AndTerm)) {
 						// A little hacky, here to make sure the root term is a AndTerm which will
 						// ensure we handle the Hidden tag properly
@@ -409,8 +400,8 @@ namespace FSpot.Widgets {
 						RootTerm.Parent = root_parent;
 						root_term = root_parent;
 					}
-					//Log.Debug ("condition = {0}", RootTerm.SqlCondition ());
-					query.TagTerm = new TagConditionWrapper (RootTerm.SqlCondition ());
+					//Log.DebugFormat ("condition = {0}", RootTerm.SqlCondition ());
+					query.TagTerm = new ConditionWrapper (RootTerm.SqlCondition ());
 				} else {
 					query.TagTerm = null;
 					//Log.Debug ("root term is null");
@@ -505,59 +496,80 @@ namespace FSpot.Widgets {
 		[GLib.ConnectBefore]
 		private void HandleMatchSelected (object sender, MatchSelectedArgs args)
 		{
-			// Delete what the user had entered in case their casing wasn't the same
-			entry.DeleteText (entry.Position - transformed_key.Length, entry.Position);
-
 			string name = args.Model.GetValue (args.Iter, TextColumn) as string;
-			//Log.Debug ("match selected..{0}", name);
+			//Log.DebugFormat ("match selected..{0}", name);
+
 			int pos = entry.Position;
+			string updated_text = completion_logic.ReplaceKey (entry.Text, name, ref pos);
 
 			completing = true;
-			entry.InsertText (name, ref pos);
+			entry.Text = updated_text;
+			entry.Position = pos;
 			completing = false;
 
-			entry.Position += name.Length;
-
 			args.RetVal = true;
-			//Log.Debug.Format ("done w/ match selected");
+			//Log.Debug ("done w/ match selected");
 		}
 
-		string last_key = String.Empty;
-		string transformed_key = String.Empty;
+		private CompletionLogic completion_logic = new CompletionLogic ();
 		public bool LogicEntryCompletionMatchFunc (EntryCompletion completion, string key, TreeIter iter)
 		{
 			if (Completing)
 				return false;
 
+			key = key == null ? null : key.Normalize(NormalizationForm.FormC);
+			string name = completion.Model.GetValue (iter, completion.TextColumn) as string;
+			int pos = entry.Position - 1;
+			return completion_logic.MatchFunc (name, key, pos);
+		}
+	}
+
+	public class CompletionLogic
+	{
+		string last_key = String.Empty;
+		string transformed_key = String.Empty;
+		int start = 0;
+
+		private static string or_op = " " + Catalog.GetString ("or") + " ";
+		private static string and_op = " " + Catalog.GetString ("and") + " ";
+
+		private static int or_op_len = or_op.Length;
+		private static int and_op_len = and_op.Length;
+
+		public bool MatchFunc (string name, string key, int pos)
+		{
 			// If this is the fist comparison for this key, convert the key (which is the entire search string)
 			// into just the part that is relevant to completing this tag name.
 			if (key != last_key) {
 				last_key = key;
 
-				int pos = entry.Position - 1;
 				if (key == null || key.Length == 0 || pos < 0 || pos > key.Length - 1)
 					transformed_key = String.Empty;
 				else if (key [pos] == '(' || key [pos] == ')' || key [pos] == ',')
 					transformed_key = String.Empty;
 				else {
-					int start = 0;
-					for (int i = entry.Position - 1; i >= 0; i--) {
-						if (key [i] == ' ' || key [i] == ')' || key [i] == '(') {
-							//Log.Debug ("have start break char at {0}", i);
+					start = 0;
+					for (int i = pos; i >= 0; i--) {
+						if (key [i] == ')' || key [i] == '(' ||
+						   (i >= and_op_len - 1 && String.Compare (key.Substring (i - and_op_len + 1, and_op_len), and_op, true) == 0) ||
+						   (i >= or_op_len - 1 && String.Compare (key.Substring (i - or_op_len + 1, or_op_len), or_op, true) == 0)) {
+							//Log.DebugFormat ("have start break char at {0}", i);
 							start = i + 1;
 							break;
 						}
 					}
 
 					int end = key.Length - 1;
-					for (int j = entry.Position - 1; j < key.Length; j++) {
-						if (key [j] == ' ' || key [j] == ')' || key [j] == '(') {
+					for (int j = pos; j < key.Length; j++) {
+						if (key [j] == ')' || key [j] == '(' ||
+						   (key.Length >= j + and_op_len && String.Compare (key.Substring (j, and_op_len), and_op, true) == 0) ||
+						   (key.Length >= j + or_op_len && String.Compare (key.Substring (j, or_op_len), or_op, true) == 0)) {
 							end = j - 1;
 							break;
 						}
 					}
 
-					//Log.Debug ("start = {0} end = {1}", start, end);
+					//Log.DebugFormat ("start = {0} end = {1}", start, end);
 
 					int len = end - start + 1;
 					if (len > 0 && start < last_key.Length)
@@ -565,20 +577,40 @@ namespace FSpot.Widgets {
 					else
 						transformed_key = String.Empty;
 				}
-				//Log.Debug ("transformed key {0} into {1}", key, transformed_key);
+				//Log.DebugFormat ("transformed key {0} into {1}", key, transformed_key);
 			}
 
 			if (transformed_key == String.Empty)
 				return false;
 
-			string name = completion.Model.GetValue (iter, completion.TextColumn) as string;
-
 			// Ignore null or names that are too short
 			if (name == null || name.Length <= transformed_key.Length)
 				return false;
 
-			//Log.Debug ("entered = {0} compared to {1}", transformed_key, name);
-			return (String.Compare (transformed_key, name.Substring(0, transformed_key.Length), true) == 0);
+			//Log.DebugFormat ("entered = {0} compared to {1}", transformed_key, name);
+
+			// Try to match key and name case insensitive
+			if (String.Compare (transformed_key, name.Substring (0, transformed_key.Length), true) == 0) {
+				return true;
+			}
+
+			// Try to match with diacritics removed from name
+			string simplified_name = StringUtil.SearchKey (name.Substring (0, transformed_key.Length));
+			//Log.DebugFormat ("entered = {0} compared to {1}", transformed_key, simplified_name);
+			return (String.Compare (transformed_key, simplified_name, true) == 0);
+		}
+
+		public string ReplaceKey (string query, string name, ref int pos)
+		{
+			// do some sanity checks first
+			if (start > query.Length) {
+				Log.Error ("ReplaceKey: start > query.length");
+				return query;
+			}
+			// move caret after inserted name, even if it was not
+			// at the end of the key
+			pos = start + name.Length;
+			return query.Substring (0, start) + name + query.Substring (start + transformed_key.Length);
 		}
 	}
 }
